@@ -4,7 +4,7 @@ use warnings;
 
 use parent 'NativeCall';
 
-our $VERSION = '0.001';    # VERSION
+our $VERSION = '0.002';    # VERSION
 
 # ABSTRACT: Perl wrapper for XGBoost C API https://github.com/dmlc/xgboost
 
@@ -12,10 +12,28 @@ sub XGBGetLastError : Args() : Native(xgboost) : Returns(string) { }
 
 sub XGDMatrixCreateFromFile : Args(string, int, opaque*) : Native(xgboost) : Returns(int) { }
 
+sub XGDMatrixCreateFromMat : Args(float *, uint64, uint64, float, opaque*) : Native(xgboost) : Returns(int) { }
+
+sub XGDMatrixSliceDMatrix : Args(opaque, int *, uint64, opaque*) : Native(xgboost) : Returns(int) { }
+
 sub XGDMatrixNumRow : Args(opaque, uint64*) : Native(xgboost) : Returns(int) { }
 
 sub XGDMatrixNumCol : Args(opaque, uint64*) : Native(xgboost) : Returns(int) { }
 
+sub XGDMatrixSaveBinary : Args(opaque, string, int) : Native(xgboost) : Returns(int) { }
+
+sub XGDMatrixSetFloatInfo : Args(opaque, string, float *, uint64) : Native(xgboost) : Returns(int) { }
+
+sub XGDMatrixSetUIntInfo : Args(opaque, string, uint32 *, uint64) : Native(xgboost) : Returns(int) { }
+
+sub XGDMatrixSetGroup : Args(opaque, uint32 *, uint64) : Native(xgboost) : Returns(int) { }
+
+sub XGDMatrixGetFloatInfo : Args(opaque, string, uint64 *, opaque *) : Native(xgboost) : Returns(int) { }
+
+sub XGDMatrixGetUIntInfo : Args(opaque, string, uint64 *, opaque *) : Native(xgboost) : Returns(int) { }
+
+sub XGDMatrixFree : Args(opaque) : Native(xgboost) : Returns(int) { }
+
 sub XGBoosterCreate : Args(opaque[], uint64, opaque*) : Native(xgboost) : Returns(int) { }
 
 sub XGBoosterFree : Args(opaque) : Native(xgboost) : Returns(int) { }
@@ -38,7 +56,7 @@ AI::XGBoost::CAPI - Perl wrapper for XGBoost C API https://github.com/dmlc/xgboo
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -118,6 +136,62 @@ a loaded data matrix
 
 =back
 
+=head2 XGDMatrixCreateFromMat
+
+Create matrix content from dense matrix
+
+Parameters:
+
+=over 4
+
+=item data 
+
+pointer to the data space
+
+=item nrow
+
+number of rows
+
+=item ncol
+
+number columns
+
+=item missing
+
+which value to represent missing value
+
+=item out
+
+created dmatrix
+
+=back
+
+=head2 XGDMatrixSliceDMatrix
+
+Create a new dmatrix from sliced content of existing matrix
+
+Parameters:
+
+=over 4
+
+=item handle
+
+instance of data matrix to be sliced
+
+=item idxset
+
+index set
+
+=item len
+
+length of index set
+
+=item out
+
+a sliced new matrix
+
+=back
+
 =head2 XGDMatrixNumRow
 
 Get number of rows.
@@ -154,6 +228,158 @@ The address to hold number of cols.
 
 =back
 
+=head2 XGDMatrixSaveBinary
+
+load a data matrix into binary file
+
+Parameters:
+
+=over 4
+
+=item handle
+
+a instance of data matrix
+
+=item fname
+
+file name
+
+=item silent
+
+print statistics when saving
+
+=back
+
+=head2 XGDMatrixSetFloatInfo
+
+Set float vector to a content in info
+
+Parameters:
+
+=over 4
+
+=item handle
+
+a instance of data matrix
+
+=item field
+
+field name, can be label, weight
+
+=item array
+
+pointer to float vector
+
+=item len
+
+length of array
+
+=back
+
+=head2 XGDMatrixSetUIntInfo
+
+Set uint32 vector to a content in info
+
+Parameters:
+
+=over 4
+
+=item handle
+
+a instance of data matrix
+
+=item field
+
+field name, can be label, weight
+
+=item array
+
+pointer to unsigned int vector
+
+=item len
+
+length of array
+
+=back
+
+=head2 XGDMatrixSetGroup
+
+Set label of the training matrix
+
+Parameters:
+
+=over 4
+
+=item handle
+
+a instance of data matrix
+
+=item group
+
+pointer to group size
+
+=item len
+
+length of the array
+
+=back
+
+=head2 XGDMatrixGetFloatInfo
+
+Get float info vector from matrix
+
+Parameters:
+
+=over 4
+
+=item handle
+
+a instance of data matrix
+
+=item field
+
+field name
+
+=item out_len
+
+used to set result length
+
+=item out_dptr
+
+pointer to the result
+
+=back
+
+=head2 XGDMatrixGetUIntInfo
+
+Get uint32 info vector from matrix
+
+Parameters:
+
+=over 4
+
+=item handle
+
+a instance of data matrix
+
+=item field
+
+field name
+
+=item out_len
+
+The length of the field
+
+=item out_dptr
+
+pointer to the result
+
+=back
+
+=head2 XGDMatrixFree
+
+Free space in data matrix
+
 =head2 XGBoosterCreate
 
 Create xgboost learner
@@ -273,7 +499,7 @@ Pablo Rodríguez González <pablo.rodriguez.gonzalez@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2017 by Pablo Rodríguez González.
+This software is Copyright (c) 2017 by Pablo Rodríguez González.
 
 This is free software, licensed under:
 
